##

    		@ counsellor
    		# admiral
    		# docent
    		# conductor
    		# cicerone

    		[ ] A DNS counsellor that proposes addresses to travel to.

    			1. 	Client asks which node to connect to.

    			2. 	Counsellor proposes like the closest node,
    				and then the client remembers that node
    				address in their DNS memory.

    					example:
    						( ) node-1 LA
    						( ) node-2 Vegas
    						( ) node-3 SF
    						( ) node-4 Portland
    						( ) node-5 Denver

    					client location: SLO

    					counsellor proposes: LA

    					Thusly, the client remembers LA,
    					and sends all their asks to the LA node.

    	important
    		https://github.com/paulc/dnslib